==> open-xchange-util-custom_1.2.0.orig.tar.bz2: open-xchange-util-custom-1.2.0/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/ConstructorServiceWithDependencies.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import java.lang.reflect.Constructor;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;
import javax.annotation.concurrent.Immutable;
import com.google.common.collect.ImmutableSet;

/**
 * {@link ConstructorServiceWithDependencies}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.0.2
 * @param <S>
 * @param <T>
 */
@ParametersAreNonnullByDefault
@Immutable
public final class ConstructorServiceWithDependencies<S, T extends S> extends ClassServiceWithDependenciesTemplate<S, T> {
    
    public static final <X, Y extends X> ServiceWithDependencies<Y> find(final Class<Y> serviceInstanceClass,
        final @Nullable Class<X> serviceClass) {
        final DependencyScan<X, Y> scan = scan(serviceInstanceClass);
        
        return new ConstructorServiceWithDependencies<X, Y>(
            scan.constructor,
            serviceInstanceClass,
            serviceClass,
            scan.dependencies,
            scan.serviceSets,
            scan.serviceListings
        );    
    }
    
    public ConstructorServiceWithDependencies(Constructor<T> constructor,
        final Class<T> serviceInstanceClass,
        @Nullable Class<S> serviceClass,
        ImmutableSet<ServiceDependency<?>> dependencies,
        ImmutableSet<Class<?>> serviceSets,
        ImmutableSet<Class<?>> serviceListings) {
        super(constructor, serviceInstanceClass, serviceClass, dependencies, serviceSets, serviceListings);
    }

}

==> open-xchange-util-custom_1.2.1.orig.tar.bz2: open-xchange-util-custom-1.2.1/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/ConstructorServiceWithDependencies.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import java.lang.reflect.Constructor;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;
import javax.annotation.concurrent.Immutable;
import com.google.common.collect.ImmutableSet;

/**
 * {@link ConstructorServiceWithDependencies}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.0.2
 * @param <S>
 * @param <T>
 */
@ParametersAreNonnullByDefault
@Immutable
public final class ConstructorServiceWithDependencies<S, T extends S> extends ClassServiceWithDependenciesTemplate<S, T> {
    
    public static final <X, Y extends X> ServiceWithDependencies<Y> find(final Class<Y> serviceInstanceClass,
        final @Nullable Class<X> serviceClass) {
        final DependencyScan<X, Y> scan = scan(serviceInstanceClass);
        
        return new ConstructorServiceWithDependencies<X, Y>(
            scan.constructor,
            serviceInstanceClass,
            serviceClass,
            scan.mandatoryDependencies,
            scan.optionalDependencies,
            scan.serviceSets,
            scan.serviceListings
        );    
    }
    
    public ConstructorServiceWithDependencies(Constructor<T> constructor,
        final Class<T> serviceInstanceClass,
        @Nullable Class<S> serviceClass,
        ImmutableSet<MandatoryServiceDependency<?>> mandatoryDependencies,
        ImmutableSet<OptionalServiceDependency<?>> optionalDependencies,
        ImmutableSet<Class<?>> serviceSets,
        ImmutableSet<Class<?>> serviceListings) {
        super(constructor, serviceInstanceClass, serviceClass, mandatoryDependencies, optionalDependencies, serviceSets, serviceListings);
    }

}
